# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/simulation_world.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.monitor_log.proto import monitor_log_pb2 as modules_dot_common_dot_monitor__log_dot_proto_dot_monitor__log__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.perception.proto import perception_obstacle_pb2 as modules_dot_perception_dot_proto_dot_perception__obstacle__pb2
from modules.planning.proto import planning_internal_pb2 as modules_dot_planning_dot_proto_dot_planning__internal__pb2
from modules.prediction.proto import feature_pb2 as modules_dot_prediction_dot_proto_dot_feature__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/simulation_world.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/dreamview/proto/simulation_world.proto\x12\x10\x61pollo.dreamview\x1a\"modules/canbus/proto/chassis.proto\x1a\x32modules/common/monitor_log/proto/monitor_log.proto\x1a$modules/common/proto/pnc_point.proto\x1a\x32modules/perception/proto/perception_obstacle.proto\x1a.modules/planning/proto/planning_internal.proto\x1a&modules/prediction/proto/feature.proto\x1a#modules/routing/proto/routing.proto\"f\n\x0cPolygonPoint\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\x12\x32\n\rgaussian_info\x18\x04 \x01(\x0b\x32\x1b.apollo.common.GaussianInfo\"_\n\nPrediction\x12\x13\n\x0bprobability\x18\x01 \x01(\x01\x12<\n\x14predicted_trajectory\x18\x02 \x03(\x0b\x32\x1e.apollo.dreamview.PolygonPoint\"\xc4\x06\n\x08\x44\x65\x63ision\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\x1f.apollo.dreamview.Decision.Type:\x06IGNORE\x12\x35\n\rpolygon_point\x18\x02 \x03(\x0b\x32\x1e.apollo.dreamview.PolygonPoint\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x12\n\nposition_x\x18\x06 \x01(\x01\x12\x12\n\nposition_y\x18\x07 \x01(\x01\x12\x13\n\x06length\x18\x08 \x01(\x01:\x03\x32.8\x12\x12\n\x05width\x18\t \x01(\x01:\x03\x31.4\x12\x13\n\x06height\x18\n \x01(\x01:\x03\x31.8\x12=\n\nstopReason\x18\x0b \x01(\x0e\x32).apollo.dreamview.Decision.StopReasonCode\x12\x38\n\x10\x63hange_lane_type\x18\x0c \x01(\x0e\x32\x1e.apollo.routing.ChangeLaneType\"Z\n\x04Type\x12\n\n\x06IGNORE\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\t\n\x05NUDGE\x10\x02\x12\t\n\x05YIELD\x10\x03\x12\x0c\n\x08OVERTAKE\x10\x04\x12\n\n\x06\x46OLLOW\x10\x05\x12\x0c\n\x08SIDEPASS\x10\x06\"\xd8\x02\n\x0eStopReasonCode\x12\x1c\n\x18STOP_REASON_HEAD_VEHICLE\x10\x01\x12\x1b\n\x17STOP_REASON_DESTINATION\x10\x02\x12\x1a\n\x16STOP_REASON_PEDESTRIAN\x10\x03\x12\x18\n\x14STOP_REASON_OBSTACLE\x10\x04\x12\x16\n\x12STOP_REASON_SIGNAL\x10\x64\x12\x19\n\x15STOP_REASON_STOP_SIGN\x10\x65\x12\x1a\n\x16STOP_REASON_YIELD_SIGN\x10\x66\x12\x1a\n\x16STOP_REASON_CLEAR_ZONE\x10g\x12\x19\n\x15STOP_REASON_CROSSWALK\x10h\x12\x19\n\x15STOP_REASON_EMERGENCY\x10i\x12\x19\n\x15STOP_REASON_NOT_READY\x10j\x12\x19\n\x15STOP_REASON_PULL_OVER\x10k\"\x88\x0c\n\x06Object\x12\n\n\x02id\x18\x01 \x01(\t\x12\x35\n\rpolygon_point\x18\x02 \x03(\x0b\x32\x1e.apollo.dreamview.PolygonPoint\x12\x0f\n\x07heading\x18\x03 \x01(\x01\x12\x10\n\x08latitude\x18\x04 \x01(\x01\x12\x11\n\tlongitude\x18\x05 \x01(\x01\x12\x12\n\nposition_x\x18\x06 \x01(\x01\x12\x12\n\nposition_y\x18\x07 \x01(\x01\x12\x13\n\x06length\x18\x08 \x01(\x01:\x03\x32.8\x12\x12\n\x05width\x18\t \x01(\x01:\x03\x31.4\x12\x13\n\x06height\x18\n \x01(\x01:\x03\x31.8\x12\r\n\x05speed\x18\x0b \x01(\x01\x12\x1a\n\x12speed_acceleration\x18\x0c \x01(\x01\x12\x12\n\nspeed_jerk\x18\r \x01(\x01\x12\x0c\n\x04spin\x18\x0e \x01(\x01\x12\x19\n\x11spin_acceleration\x18\x0f \x01(\x01\x12\x11\n\tspin_jerk\x18\x10 \x01(\x01\x12\x15\n\rspeed_heading\x18\x11 \x01(\x01\x12\r\n\x05kappa\x18\x12 \x01(\x01\x12\x0e\n\x06\x64kappa\x18# \x01(\x01\x12\x12\n\nsignal_set\x18\x13 \x03(\t\x12\x16\n\x0e\x63urrent_signal\x18\x14 \x01(\t\x12\x15\n\rtimestamp_sec\x18\x15 \x01(\x01\x12,\n\x08\x64\x65\x63ision\x18\x16 \x03(\x0b\x32\x1a.apollo.dreamview.Decision\x12\x1f\n\x10yielded_obstacle\x18  \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13throttle_percentage\x18\x17 \x01(\x01\x12\x18\n\x10\x62rake_percentage\x18\x18 \x01(\x01\x12\x1b\n\x13steering_percentage\x18\x19 \x01(\x01\x12\x16\n\x0esteering_angle\x18\x1a \x01(\x01\x12\x16\n\x0esteering_ratio\x18\x1b \x01(\x01\x12\x1a\n\x12\x62\x61ttery_percentage\x18& \x01(\x05\x12:\n\rgear_location\x18\' \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12>\n\x0e\x64isengage_type\x18\x1c \x01(\x0e\x32&.apollo.dreamview.Object.DisengageType\x12+\n\x04type\x18\x1d \x01(\x0e\x32\x1d.apollo.dreamview.Object.Type\x12?\n\x08sub_type\x18\" \x01(\x0e\x32-.apollo.perception.PerceptionObstacle.SubType\x12\x30\n\nprediction\x18\x1e \x03(\x0b\x32\x1c.apollo.dreamview.Prediction\x12\x15\n\nconfidence\x18\x1f \x01(\x01:\x01\x31\x12>\n\x11obstacle_priority\x18! \x01(\x0b\x32#.apollo.prediction.ObstaclePriority\x12J\n\x06source\x18$ \x01(\x0e\x32,.apollo.perception.PerceptionObstacle.Source:\x0cHOST_VEHICLE\x12\x33\n\x08v2x_info\x18% \x01(\x0b\x32!.apollo.perception.V2XInformation\"\xc4\x01\n\rDisengageType\x12\x12\n\x0e\x44ISENGAGE_NONE\x10\x00\x12\x15\n\x11\x44ISENGAGE_UNKNOWN\x10\x01\x12\x14\n\x10\x44ISENGAGE_MANUAL\x10\x02\x12\x17\n\x13\x44ISENGAGE_EMERGENCY\x10\x03\x12\x1d\n\x19\x44ISENGAGE_AUTO_STEER_ONLY\x10\x04\x12\x1d\n\x19\x44ISENGAGE_AUTO_SPEED_ONLY\x10\x05\x12\x1b\n\x17\x44ISENGAGE_CHASSIS_ERROR\x10\x06\"\x80\x01\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fUNKNOWN_MOVABLE\x10\x01\x12\x15\n\x11UNKNOWN_UNMOVABLE\x10\x02\x12\x0e\n\nPEDESTRIAN\x10\x03\x12\x0b\n\x07\x42ICYCLE\x10\x04\x12\x0b\n\x07VEHICLE\x10\x05\x12\x0b\n\x07VIRTUAL\x10\x06\x12\x08\n\x04\x43IPV\x10\x07\"\x9e\x01\n\nDelaysInMs\x12\x0f\n\x07\x63hassis\x18\x01 \x01(\x01\x12\x14\n\x0clocalization\x18\x03 \x01(\x01\x12\x1b\n\x13perception_obstacle\x18\x04 \x01(\x01\x12\x10\n\x08planning\x18\x05 \x01(\x01\x12\x12\n\nprediction\x18\x07 \x01(\x01\x12\x15\n\rtraffic_light\x18\x08 \x01(\x01\x12\x0f\n\x07\x63ontrol\x18\t \x01(\x01\":\n\tRoutePath\x12-\n\x05point\x18\x01 \x03(\x0b\x32\x1e.apollo.dreamview.PolygonPoint\"7\n\x07Latency\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x15\n\rtotal_time_ms\x18\x02 \x01(\x01\"\xe8\x01\n\rMapElementIds\x12\x0c\n\x04lane\x18\x01 \x03(\t\x12\x11\n\tcrosswalk\x18\x02 \x03(\t\x12\x10\n\x08junction\x18\x03 \x03(\t\x12\x0e\n\x06signal\x18\x04 \x03(\t\x12\x11\n\tstop_sign\x18\x05 \x03(\t\x12\r\n\x05yield\x18\x06 \x03(\t\x12\x0f\n\x07overlap\x18\x07 \x03(\t\x12\x0c\n\x04road\x18\x08 \x03(\t\x12\x12\n\nclear_area\x18\t \x03(\t\x12\x15\n\rparking_space\x18\n \x03(\t\x12\x12\n\nspeed_bump\x18\x0b \x03(\t\x12\x14\n\x0cpnc_junction\x18\x0c \x03(\t\"\xa7\x01\n\x0b\x43ontrolData\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x15\n\rstation_error\x18\x02 \x01(\x01\x12\x15\n\rlateral_error\x18\x03 \x01(\x01\x12\x15\n\rheading_error\x18\x04 \x01(\x01\x12<\n\x14\x63urrent_target_point\x18\x05 \x01(\x0b\x32\x1e.apollo.common.TrajectoryPoint\"^\n\x0cNotification\x12\x15\n\rtimestamp_sec\x18\x01 \x01(\x01\x12\x37\n\x04item\x18\x02 \x01(\x0b\x32).apollo.common.monitor.MonitorMessageItem\"J\n\x12SensorMeasurements\x12\x34\n\x12sensor_measurement\x18\x01 \x03(\x0b\x32\x18.apollo.dreamview.Object\"\xab\x0c\n\x0fSimulationWorld\x12\x11\n\ttimestamp\x18\x01 \x01(\x01\x12\x14\n\x0csequence_num\x18\x02 \x01(\r\x12(\n\x06object\x18\x03 \x03(\x0b\x32\x18.apollo.dreamview.Object\x12\x32\n\x10\x61uto_driving_car\x18\x04 \x01(\x0b\x32\x18.apollo.dreamview.Object\x12\x30\n\x0etraffic_signal\x18\x05 \x01(\x0b\x32\x18.apollo.dreamview.Object\x12/\n\nroute_path\x18\x06 \x03(\x0b\x32\x1b.apollo.dreamview.RoutePath\x12\x14\n\x0crouting_time\x18\x07 \x01(\x01\x12\x35\n\x13planning_trajectory\x18\x08 \x03(\x0b\x32\x18.apollo.dreamview.Object\x12/\n\tmain_stop\x18\t \x01(\x0b\x32\x18.apollo.dreamview.ObjectB\x02\x18\x01\x12/\n\rmain_decision\x18\n \x01(\x0b\x32\x18.apollo.dreamview.Object\x12\x13\n\x0bspeed_limit\x18\x0b \x01(\x01\x12+\n\x05\x64\x65lay\x18\x0c \x01(\x0b\x32\x1c.apollo.dreamview.DelaysInMs\x12:\n\x07monitor\x18\r \x01(\x0b\x32%.apollo.common.monitor.MonitorMessageB\x02\x18\x01\x12\x34\n\x0cnotification\x18\x0e \x03(\x0b\x32\x1e.apollo.dreamview.Notification\x12\x15\n\rengage_advice\x18\x0f \x01(\t\x12?\n\x07latency\x18\x10 \x03(\x0b\x32..apollo.dreamview.SimulationWorld.LatencyEntry\x12\x38\n\x0fmap_element_ids\x18\x11 \x01(\x0b\x32\x1f.apollo.dreamview.MapElementIds\x12\x10\n\x08map_hash\x18\x12 \x01(\x04\x12\x12\n\nmap_radius\x18\x13 \x01(\x01\x12=\n\rplanning_data\x18\x14 \x01(\x0b\x32&.apollo.planning_internal.PlanningData\x12%\n\x03gps\x18\x15 \x01(\x0b\x32\x18.apollo.dreamview.Object\x12\x33\n\x0blane_marker\x18\x16 \x01(\x0b\x32\x1e.apollo.perception.LaneMarkers\x12\x33\n\x0c\x63ontrol_data\x18\x17 \x01(\x0b\x32\x1d.apollo.dreamview.ControlData\x12,\n\x0fnavigation_path\x18\x18 \x03(\x0b\x32\x13.apollo.common.Path\x12\x19\n\x0bis_rss_safe\x18\x19 \x01(\x08:\x04true\x12\x35\n\x13shadow_localization\x18\x1a \x01(\x0b\x32\x18.apollo.dreamview.Object\x12\x32\n\x10perceived_signal\x18\x1b \x03(\x0b\x32\x18.apollo.dreamview.Object\x12?\n\x07stories\x18\x1c \x03(\x0b\x32..apollo.dreamview.SimulationWorld.StoriesEntry\x12V\n\x13sensor_measurements\x18\x1d \x03(\x0b\x32\x39.apollo.dreamview.SimulationWorld.SensorMeasurementsEntry\x12\x1a\n\x0bis_siren_on\x18\x1e \x01(\x08:\x05\x66\x61lse\x1aI\n\x0cLatencyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b\x32\x19.apollo.dreamview.Latency:\x02\x38\x01\x1a.\n\x0cStoriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a_\n\x17SensorMeasurementsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.apollo.dreamview.SensorMeasurements:\x02\x38\x01'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_monitor__log_dot_proto_dot_monitor__log__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_perception_dot_proto_dot_perception__obstacle__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_planning__internal__pb2.DESCRIPTOR,modules_dot_prediction_dot_proto_dot_feature__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])



_DECISION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.dreamview.Decision.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IGNORE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NUDGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YIELD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OVERTAKE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOLLOW', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIDEPASS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=972,
  serialized_end=1062,
)
_sym_db.RegisterEnumDescriptor(_DECISION_TYPE)

_DECISION_STOPREASONCODE = _descriptor.EnumDescriptor(
  name='StopReasonCode',
  full_name='apollo.dreamview.Decision.StopReasonCode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_HEAD_VEHICLE', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_DESTINATION', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PEDESTRIAN', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_OBSTACLE', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_SIGNAL', index=4, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_STOP_SIGN', index=5, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_YIELD_SIGN', index=6, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_CLEAR_ZONE', index=7, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_CROSSWALK', index=8, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_EMERGENCY', index=9, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_NOT_READY', index=10, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOP_REASON_PULL_OVER', index=11, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1065,
  serialized_end=1409,
)
_sym_db.RegisterEnumDescriptor(_DECISION_STOPREASONCODE)

_OBJECT_DISENGAGETYPE = _descriptor.EnumDescriptor(
  name='DisengageType',
  full_name='apollo.dreamview.Object.DisengageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_MANUAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_EMERGENCY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_AUTO_STEER_ONLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_AUTO_SPEED_ONLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISENGAGE_CHASSIS_ERROR', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2629,
  serialized_end=2825,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_DISENGAGETYPE)

_OBJECT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.dreamview.Object.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_MOVABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_UNMOVABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PEDESTRIAN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BICYCLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEHICLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIRTUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIPV', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2828,
  serialized_end=2956,
)
_sym_db.RegisterEnumDescriptor(_OBJECT_TYPE)


_POLYGONPOINT = _descriptor.Descriptor(
  name='PolygonPoint',
  full_name='apollo.dreamview.PolygonPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.dreamview.PolygonPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.dreamview.PolygonPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.dreamview.PolygonPoint.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gaussian_info', full_name='apollo.dreamview.PolygonPoint.gaussian_info', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=473,
)


_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='apollo.dreamview.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='apollo.dreamview.Prediction.probability', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predicted_trajectory', full_name='apollo.dreamview.Prediction.predicted_trajectory', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=570,
)


_DECISION = _descriptor.Descriptor(
  name='Decision',
  full_name='apollo.dreamview.Decision',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.dreamview.Decision.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.dreamview.Decision.polygon_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.dreamview.Decision.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='apollo.dreamview.Decision.latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='apollo.dreamview.Decision.longitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.dreamview.Decision.position_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.dreamview.Decision.position_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.dreamview.Decision.length', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.dreamview.Decision.width', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.dreamview.Decision.height', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stopReason', full_name='apollo.dreamview.Decision.stopReason', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='change_lane_type', full_name='apollo.dreamview.Decision.change_lane_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DECISION_TYPE,
    _DECISION_STOPREASONCODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=1409,
)


_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='apollo.dreamview.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.dreamview.Object.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon_point', full_name='apollo.dreamview.Object.polygon_point', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.dreamview.Object.heading', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latitude', full_name='apollo.dreamview.Object.latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='apollo.dreamview.Object.longitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_x', full_name='apollo.dreamview.Object.position_x', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_y', full_name='apollo.dreamview.Object.position_y', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.dreamview.Object.length', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.dreamview.Object.width', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.4),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.dreamview.Object.height', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.dreamview.Object.speed', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_acceleration', full_name='apollo.dreamview.Object.speed_acceleration', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_jerk', full_name='apollo.dreamview.Object.speed_jerk', index=12,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spin', full_name='apollo.dreamview.Object.spin', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spin_acceleration', full_name='apollo.dreamview.Object.spin_acceleration', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spin_jerk', full_name='apollo.dreamview.Object.spin_jerk', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_heading', full_name='apollo.dreamview.Object.speed_heading', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.dreamview.Object.kappa', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dkappa', full_name='apollo.dreamview.Object.dkappa', index=18,
      number=35, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_set', full_name='apollo.dreamview.Object.signal_set', index=19,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_signal', full_name='apollo.dreamview.Object.current_signal', index=20,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.dreamview.Object.timestamp_sec', index=21,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decision', full_name='apollo.dreamview.Object.decision', index=22,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yielded_obstacle', full_name='apollo.dreamview.Object.yielded_obstacle', index=23,
      number=32, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throttle_percentage', full_name='apollo.dreamview.Object.throttle_percentage', index=24,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brake_percentage', full_name='apollo.dreamview.Object.brake_percentage', index=25,
      number=24, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_percentage', full_name='apollo.dreamview.Object.steering_percentage', index=26,
      number=25, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_angle', full_name='apollo.dreamview.Object.steering_angle', index=27,
      number=26, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_ratio', full_name='apollo.dreamview.Object.steering_ratio', index=28,
      number=27, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_percentage', full_name='apollo.dreamview.Object.battery_percentage', index=29,
      number=38, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear_location', full_name='apollo.dreamview.Object.gear_location', index=30,
      number=39, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disengage_type', full_name='apollo.dreamview.Object.disengage_type', index=31,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.dreamview.Object.type', index=32,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sub_type', full_name='apollo.dreamview.Object.sub_type', index=33,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='apollo.dreamview.Object.prediction', index=34,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.dreamview.Object.confidence', index=35,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='obstacle_priority', full_name='apollo.dreamview.Object.obstacle_priority', index=36,
      number=33, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='apollo.dreamview.Object.source', index=37,
      number=36, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v2x_info', full_name='apollo.dreamview.Object.v2x_info', index=38,
      number=37, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OBJECT_DISENGAGETYPE,
    _OBJECT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1412,
  serialized_end=2956,
)


_DELAYSINMS = _descriptor.Descriptor(
  name='DelaysInMs',
  full_name='apollo.dreamview.DelaysInMs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chassis', full_name='apollo.dreamview.DelaysInMs.chassis', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.dreamview.DelaysInMs.localization', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perception_obstacle', full_name='apollo.dreamview.DelaysInMs.perception_obstacle', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning', full_name='apollo.dreamview.DelaysInMs.planning', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prediction', full_name='apollo.dreamview.DelaysInMs.prediction', index=4,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light', full_name='apollo.dreamview.DelaysInMs.traffic_light', index=5,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control', full_name='apollo.dreamview.DelaysInMs.control', index=6,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2959,
  serialized_end=3117,
)


_ROUTEPATH = _descriptor.Descriptor(
  name='RoutePath',
  full_name='apollo.dreamview.RoutePath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='apollo.dreamview.RoutePath.point', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3119,
  serialized_end=3177,
)


_LATENCY = _descriptor.Descriptor(
  name='Latency',
  full_name='apollo.dreamview.Latency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.dreamview.Latency.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_time_ms', full_name='apollo.dreamview.Latency.total_time_ms', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3179,
  serialized_end=3234,
)


_MAPELEMENTIDS = _descriptor.Descriptor(
  name='MapElementIds',
  full_name='apollo.dreamview.MapElementIds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lane', full_name='apollo.dreamview.MapElementIds.lane', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk', full_name='apollo.dreamview.MapElementIds.crosswalk', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction', full_name='apollo.dreamview.MapElementIds.junction', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='apollo.dreamview.MapElementIds.signal', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign', full_name='apollo.dreamview.MapElementIds.stop_sign', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield', full_name='apollo.dreamview.MapElementIds.yield', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overlap', full_name='apollo.dreamview.MapElementIds.overlap', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road', full_name='apollo.dreamview.MapElementIds.road', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area', full_name='apollo.dreamview.MapElementIds.clear_area', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space', full_name='apollo.dreamview.MapElementIds.parking_space', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bump', full_name='apollo.dreamview.MapElementIds.speed_bump', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pnc_junction', full_name='apollo.dreamview.MapElementIds.pnc_junction', index=11,
      number=12, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3237,
  serialized_end=3469,
)


_CONTROLDATA = _descriptor.Descriptor(
  name='ControlData',
  full_name='apollo.dreamview.ControlData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.dreamview.ControlData.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_error', full_name='apollo.dreamview.ControlData.station_error', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lateral_error', full_name='apollo.dreamview.ControlData.lateral_error', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_error', full_name='apollo.dreamview.ControlData.heading_error', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_target_point', full_name='apollo.dreamview.ControlData.current_target_point', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3472,
  serialized_end=3639,
)


_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='apollo.dreamview.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_sec', full_name='apollo.dreamview.Notification.timestamp_sec', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='apollo.dreamview.Notification.item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3641,
  serialized_end=3735,
)


_SENSORMEASUREMENTS = _descriptor.Descriptor(
  name='SensorMeasurements',
  full_name='apollo.dreamview.SensorMeasurements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensor_measurement', full_name='apollo.dreamview.SensorMeasurements.sensor_measurement', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3737,
  serialized_end=3811,
)


_SIMULATIONWORLD_LATENCYENTRY = _descriptor.Descriptor(
  name='LatencyEntry',
  full_name='apollo.dreamview.SimulationWorld.LatencyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.SimulationWorld.LatencyEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.SimulationWorld.LatencyEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5175,
  serialized_end=5248,
)

_SIMULATIONWORLD_STORIESENTRY = _descriptor.Descriptor(
  name='StoriesEntry',
  full_name='apollo.dreamview.SimulationWorld.StoriesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.SimulationWorld.StoriesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.SimulationWorld.StoriesEntry.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5250,
  serialized_end=5296,
)

_SIMULATIONWORLD_SENSORMEASUREMENTSENTRY = _descriptor.Descriptor(
  name='SensorMeasurementsEntry',
  full_name='apollo.dreamview.SimulationWorld.SensorMeasurementsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.dreamview.SimulationWorld.SensorMeasurementsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.dreamview.SimulationWorld.SensorMeasurementsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5298,
  serialized_end=5393,
)

_SIMULATIONWORLD = _descriptor.Descriptor(
  name='SimulationWorld',
  full_name='apollo.dreamview.SimulationWorld',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.dreamview.SimulationWorld.timestamp', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence_num', full_name='apollo.dreamview.SimulationWorld.sequence_num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='apollo.dreamview.SimulationWorld.object', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_driving_car', full_name='apollo.dreamview.SimulationWorld.auto_driving_car', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_signal', full_name='apollo.dreamview.SimulationWorld.traffic_signal', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='route_path', full_name='apollo.dreamview.SimulationWorld.route_path', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_time', full_name='apollo.dreamview.SimulationWorld.routing_time', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_trajectory', full_name='apollo.dreamview.SimulationWorld.planning_trajectory', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_stop', full_name='apollo.dreamview.SimulationWorld.main_stop', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='main_decision', full_name='apollo.dreamview.SimulationWorld.main_decision', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_limit', full_name='apollo.dreamview.SimulationWorld.speed_limit', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='apollo.dreamview.SimulationWorld.delay', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitor', full_name='apollo.dreamview.SimulationWorld.monitor', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notification', full_name='apollo.dreamview.SimulationWorld.notification', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.dreamview.SimulationWorld.engage_advice', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency', full_name='apollo.dreamview.SimulationWorld.latency', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_element_ids', full_name='apollo.dreamview.SimulationWorld.map_element_ids', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_hash', full_name='apollo.dreamview.SimulationWorld.map_hash', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='map_radius', full_name='apollo.dreamview.SimulationWorld.map_radius', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='planning_data', full_name='apollo.dreamview.SimulationWorld.planning_data', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps', full_name='apollo.dreamview.SimulationWorld.gps', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_marker', full_name='apollo.dreamview.SimulationWorld.lane_marker', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_data', full_name='apollo.dreamview.SimulationWorld.control_data', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navigation_path', full_name='apollo.dreamview.SimulationWorld.navigation_path', index=23,
      number=24, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_rss_safe', full_name='apollo.dreamview.SimulationWorld.is_rss_safe', index=24,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shadow_localization', full_name='apollo.dreamview.SimulationWorld.shadow_localization', index=25,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perceived_signal', full_name='apollo.dreamview.SimulationWorld.perceived_signal', index=26,
      number=27, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stories', full_name='apollo.dreamview.SimulationWorld.stories', index=27,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sensor_measurements', full_name='apollo.dreamview.SimulationWorld.sensor_measurements', index=28,
      number=29, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_siren_on', full_name='apollo.dreamview.SimulationWorld.is_siren_on', index=29,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SIMULATIONWORLD_LATENCYENTRY, _SIMULATIONWORLD_STORIESENTRY, _SIMULATIONWORLD_SENSORMEASUREMENTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3814,
  serialized_end=5393,
)

_POLYGONPOINT.fields_by_name['gaussian_info'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._GAUSSIANINFO
_PREDICTION.fields_by_name['predicted_trajectory'].message_type = _POLYGONPOINT
_DECISION.fields_by_name['type'].enum_type = _DECISION_TYPE
_DECISION.fields_by_name['polygon_point'].message_type = _POLYGONPOINT
_DECISION.fields_by_name['stopReason'].enum_type = _DECISION_STOPREASONCODE
_DECISION.fields_by_name['change_lane_type'].enum_type = modules_dot_routing_dot_proto_dot_routing__pb2._CHANGELANETYPE
_DECISION_TYPE.containing_type = _DECISION
_DECISION_STOPREASONCODE.containing_type = _DECISION
_OBJECT.fields_by_name['polygon_point'].message_type = _POLYGONPOINT
_OBJECT.fields_by_name['decision'].message_type = _DECISION
_OBJECT.fields_by_name['gear_location'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_OBJECT.fields_by_name['disengage_type'].enum_type = _OBJECT_DISENGAGETYPE
_OBJECT.fields_by_name['type'].enum_type = _OBJECT_TYPE
_OBJECT.fields_by_name['sub_type'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_SUBTYPE
_OBJECT.fields_by_name['prediction'].message_type = _PREDICTION
_OBJECT.fields_by_name['obstacle_priority'].message_type = modules_dot_prediction_dot_proto_dot_feature__pb2._OBSTACLEPRIORITY
_OBJECT.fields_by_name['source'].enum_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._PERCEPTIONOBSTACLE_SOURCE
_OBJECT.fields_by_name['v2x_info'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._V2XINFORMATION
_OBJECT_DISENGAGETYPE.containing_type = _OBJECT
_OBJECT_TYPE.containing_type = _OBJECT
_ROUTEPATH.fields_by_name['point'].message_type = _POLYGONPOINT
_CONTROLDATA.fields_by_name['current_target_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_NOTIFICATION.fields_by_name['item'].message_type = modules_dot_common_dot_monitor__log_dot_proto_dot_monitor__log__pb2._MONITORMESSAGEITEM
_SENSORMEASUREMENTS.fields_by_name['sensor_measurement'].message_type = _OBJECT
_SIMULATIONWORLD_LATENCYENTRY.fields_by_name['value'].message_type = _LATENCY
_SIMULATIONWORLD_LATENCYENTRY.containing_type = _SIMULATIONWORLD
_SIMULATIONWORLD_STORIESENTRY.containing_type = _SIMULATIONWORLD
_SIMULATIONWORLD_SENSORMEASUREMENTSENTRY.fields_by_name['value'].message_type = _SENSORMEASUREMENTS
_SIMULATIONWORLD_SENSORMEASUREMENTSENTRY.containing_type = _SIMULATIONWORLD
_SIMULATIONWORLD.fields_by_name['object'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['auto_driving_car'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['traffic_signal'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['route_path'].message_type = _ROUTEPATH
_SIMULATIONWORLD.fields_by_name['planning_trajectory'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['main_stop'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['main_decision'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['delay'].message_type = _DELAYSINMS
_SIMULATIONWORLD.fields_by_name['monitor'].message_type = modules_dot_common_dot_monitor__log_dot_proto_dot_monitor__log__pb2._MONITORMESSAGE
_SIMULATIONWORLD.fields_by_name['notification'].message_type = _NOTIFICATION
_SIMULATIONWORLD.fields_by_name['latency'].message_type = _SIMULATIONWORLD_LATENCYENTRY
_SIMULATIONWORLD.fields_by_name['map_element_ids'].message_type = _MAPELEMENTIDS
_SIMULATIONWORLD.fields_by_name['planning_data'].message_type = modules_dot_planning_dot_proto_dot_planning__internal__pb2._PLANNINGDATA
_SIMULATIONWORLD.fields_by_name['gps'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['lane_marker'].message_type = modules_dot_perception_dot_proto_dot_perception__obstacle__pb2._LANEMARKERS
_SIMULATIONWORLD.fields_by_name['control_data'].message_type = _CONTROLDATA
_SIMULATIONWORLD.fields_by_name['navigation_path'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATH
_SIMULATIONWORLD.fields_by_name['shadow_localization'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['perceived_signal'].message_type = _OBJECT
_SIMULATIONWORLD.fields_by_name['stories'].message_type = _SIMULATIONWORLD_STORIESENTRY
_SIMULATIONWORLD.fields_by_name['sensor_measurements'].message_type = _SIMULATIONWORLD_SENSORMEASUREMENTSENTRY
DESCRIPTOR.message_types_by_name['PolygonPoint'] = _POLYGONPOINT
DESCRIPTOR.message_types_by_name['Prediction'] = _PREDICTION
DESCRIPTOR.message_types_by_name['Decision'] = _DECISION
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
DESCRIPTOR.message_types_by_name['DelaysInMs'] = _DELAYSINMS
DESCRIPTOR.message_types_by_name['RoutePath'] = _ROUTEPATH
DESCRIPTOR.message_types_by_name['Latency'] = _LATENCY
DESCRIPTOR.message_types_by_name['MapElementIds'] = _MAPELEMENTIDS
DESCRIPTOR.message_types_by_name['ControlData'] = _CONTROLDATA
DESCRIPTOR.message_types_by_name['Notification'] = _NOTIFICATION
DESCRIPTOR.message_types_by_name['SensorMeasurements'] = _SENSORMEASUREMENTS
DESCRIPTOR.message_types_by_name['SimulationWorld'] = _SIMULATIONWORLD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolygonPoint = _reflection.GeneratedProtocolMessageType('PolygonPoint', (_message.Message,), {
  'DESCRIPTOR' : _POLYGONPOINT,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.PolygonPoint)
  })
_sym_db.RegisterMessage(PolygonPoint)

Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTION,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Prediction)
  })
_sym_db.RegisterMessage(Prediction)

Decision = _reflection.GeneratedProtocolMessageType('Decision', (_message.Message,), {
  'DESCRIPTOR' : _DECISION,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Decision)
  })
_sym_db.RegisterMessage(Decision)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Object)
  })
_sym_db.RegisterMessage(Object)

DelaysInMs = _reflection.GeneratedProtocolMessageType('DelaysInMs', (_message.Message,), {
  'DESCRIPTOR' : _DELAYSINMS,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.DelaysInMs)
  })
_sym_db.RegisterMessage(DelaysInMs)

RoutePath = _reflection.GeneratedProtocolMessageType('RoutePath', (_message.Message,), {
  'DESCRIPTOR' : _ROUTEPATH,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.RoutePath)
  })
_sym_db.RegisterMessage(RoutePath)

Latency = _reflection.GeneratedProtocolMessageType('Latency', (_message.Message,), {
  'DESCRIPTOR' : _LATENCY,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Latency)
  })
_sym_db.RegisterMessage(Latency)

MapElementIds = _reflection.GeneratedProtocolMessageType('MapElementIds', (_message.Message,), {
  'DESCRIPTOR' : _MAPELEMENTIDS,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.MapElementIds)
  })
_sym_db.RegisterMessage(MapElementIds)

ControlData = _reflection.GeneratedProtocolMessageType('ControlData', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLDATA,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.ControlData)
  })
_sym_db.RegisterMessage(ControlData)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATION,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.Notification)
  })
_sym_db.RegisterMessage(Notification)

SensorMeasurements = _reflection.GeneratedProtocolMessageType('SensorMeasurements', (_message.Message,), {
  'DESCRIPTOR' : _SENSORMEASUREMENTS,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.SensorMeasurements)
  })
_sym_db.RegisterMessage(SensorMeasurements)

SimulationWorld = _reflection.GeneratedProtocolMessageType('SimulationWorld', (_message.Message,), {

  'LatencyEntry' : _reflection.GeneratedProtocolMessageType('LatencyEntry', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATIONWORLD_LATENCYENTRY,
    '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.SimulationWorld.LatencyEntry)
    })
  ,

  'StoriesEntry' : _reflection.GeneratedProtocolMessageType('StoriesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATIONWORLD_STORIESENTRY,
    '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.SimulationWorld.StoriesEntry)
    })
  ,

  'SensorMeasurementsEntry' : _reflection.GeneratedProtocolMessageType('SensorMeasurementsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATIONWORLD_SENSORMEASUREMENTSENTRY,
    '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
    # @@protoc_insertion_point(class_scope:apollo.dreamview.SimulationWorld.SensorMeasurementsEntry)
    })
  ,
  'DESCRIPTOR' : _SIMULATIONWORLD,
  '__module__' : 'modules.dreamview.proto.simulation_world_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.SimulationWorld)
  })
_sym_db.RegisterMessage(SimulationWorld)
_sym_db.RegisterMessage(SimulationWorld.LatencyEntry)
_sym_db.RegisterMessage(SimulationWorld.StoriesEntry)
_sym_db.RegisterMessage(SimulationWorld.SensorMeasurementsEntry)


_SIMULATIONWORLD_LATENCYENTRY._options = None
_SIMULATIONWORLD_STORIESENTRY._options = None
_SIMULATIONWORLD_SENSORMEASUREMENTSENTRY._options = None
_SIMULATIONWORLD.fields_by_name['main_stop']._options = None
_SIMULATIONWORLD.fields_by_name['monitor']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/local_view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.control.proto import pad_msg_pb2 as modules_dot_control_dot_proto_dot_pad__msg__pb2
from modules.localization.proto import localization_pb2 as modules_dot_localization_dot_proto_dot_localization__pb2
from modules.planning.proto import planning_pb2 as modules_dot_planning_dot_proto_dot_planning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/local_view.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/control/proto/local_view.proto\x12\x0e\x61pollo.control\x1a\"modules/canbus/proto/chassis.proto\x1a!modules/common/proto/header.proto\x1a#modules/control/proto/pad_msg.proto\x1a-modules/localization/proto/localization.proto\x1a%modules/planning/proto/planning.proto\"\xfd\x01\n\tLocalView\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\'\n\x07\x63hassis\x18\x02 \x01(\x0b\x32\x16.apollo.canbus.Chassis\x12\x32\n\ntrajectory\x18\x03 \x01(\x0b\x32\x1e.apollo.planning.ADCTrajectory\x12?\n\x0clocalization\x18\x04 \x01(\x0b\x32).apollo.localization.LocalizationEstimate\x12+\n\x07pad_msg\x18\x05 \x01(\x0b\x32\x1a.apollo.control.PadMessage'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_pad__msg__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_localization__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_planning__pb2.DESCRIPTOR,])




_LOCALVIEW = _descriptor.Descriptor(
  name='LocalView',
  full_name='apollo.control.LocalView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.control.LocalView.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chassis', full_name='apollo.control.LocalView.chassis', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory', full_name='apollo.control.LocalView.trajectory', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.control.LocalView.localization', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pad_msg', full_name='apollo.control.LocalView.pad_msg', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=506,
)

_LOCALVIEW.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_LOCALVIEW.fields_by_name['chassis'].message_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS
_LOCALVIEW.fields_by_name['trajectory'].message_type = modules_dot_planning_dot_proto_dot_planning__pb2._ADCTRAJECTORY
_LOCALVIEW.fields_by_name['localization'].message_type = modules_dot_localization_dot_proto_dot_localization__pb2._LOCALIZATIONESTIMATE
_LOCALVIEW.fields_by_name['pad_msg'].message_type = modules_dot_control_dot_proto_dot_pad__msg__pb2._PADMESSAGE
DESCRIPTOR.message_types_by_name['LocalView'] = _LOCALVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocalView = _reflection.GeneratedProtocolMessageType('LocalView', (_message.Message,), {
  'DESCRIPTOR' : _LOCALVIEW,
  '__module__' : 'modules.control.proto.local_view_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.LocalView)
  })
_sym_db.RegisterMessage(LocalView)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_rsi.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fmodules/v2x/proto/v2x_rsi.proto\x12\napollo.v2x\x1a!modules/common/proto/header.proto\" \n\x08RsiPoint\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\xd4\x01\n\x06RsiMsg\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12$\n\x06points\x18\x02 \x03(\x0b\x32\x14.apollo.v2x.RsiPoint\x12\r\n\x05speed\x18\x03 \x01(\x01\x12\x11\n\tlow_speed\x18\x04 \x01(\x01\x12\x12\n\nhigh_speed\x18\x05 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x10\n\x08rsi_type\x18\x07 \x01(\x05\x12\x0e\n\x06radius\x18\x08 \x01(\x01\x12\x10\n\x08priority\x18\t \x01(\x05'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_RSIPOINT = _descriptor.Descriptor(
  name='RsiPoint',
  full_name='apollo.v2x.RsiPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.v2x.RsiPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.v2x.RsiPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=114,
)


_RSIMSG = _descriptor.Descriptor(
  name='RsiMsg',
  full_name='apollo.v2x.RsiMsg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.v2x.RsiMsg.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='apollo.v2x.RsiMsg.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='apollo.v2x.RsiMsg.speed', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_speed', full_name='apollo.v2x.RsiMsg.low_speed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high_speed', full_name='apollo.v2x.RsiMsg.high_speed', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='apollo.v2x.RsiMsg.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsi_type', full_name='apollo.v2x.RsiMsg.rsi_type', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='apollo.v2x.RsiMsg.radius', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='apollo.v2x.RsiMsg.priority', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=329,
)

_RSIMSG.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_RSIMSG.fields_by_name['points'].message_type = _RSIPOINT
DESCRIPTOR.message_types_by_name['RsiPoint'] = _RSIPOINT
DESCRIPTOR.message_types_by_name['RsiMsg'] = _RSIMSG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RsiPoint = _reflection.GeneratedProtocolMessageType('RsiPoint', (_message.Message,), {
  'DESCRIPTOR' : _RSIPOINT,
  '__module__' : 'modules.v2x.proto.v2x_rsi_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.RsiPoint)
  })
_sym_db.RegisterMessage(RsiPoint)

RsiMsg = _reflection.GeneratedProtocolMessageType('RsiMsg', (_message.Message,), {
  'DESCRIPTOR' : _RSIMSG,
  '__module__' : 'modules.v2x.proto.v2x_rsi_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.RsiMsg)
  })
_sym_db.RegisterMessage(RsiMsg)


# @@protoc_insertion_point(module_scope)
